# Installation

Pygount is available from [PyPI](https://pypi.python.org/pypi/pygount) and can be installed by running:

```bash
pip install pygount
```

Using [uv](https://docs.astral.sh/uv/), it can also run directly. For example:

```bash
uvx pygount --version
```
